@@ -18,10 +18,11 @@ import pkg_resources
 
 from radicale import web
 
+from etesync_dav.mac_helpers import has_ssl
 
 class Web(web.BaseWeb):
-    def __init__(self, configuration, logger):
-        super().__init__(configuration, logger)
+    def __init__(self, configuration):
+        super().__init__(configuration)
         self.folder = pkg_resources.resource_filename(__name__, "web")
 
     def _call(self, environ, base_prefix, path, user):
@@ -32,6 +33,8 @@ class Web(web.BaseWeb):
             ret_response.append(int(status.split()[0]))
             ret_response.append(dict(headers))
 
+        if has_ssl():
+            environ['wsgi.url_scheme'] = 'https'
         body = list(app(environ, start_response))[0]
         ret_response.append(body)
         return tuple(ret_response)
