@@ -26,7 +26,7 @@ from wtforms.validators import DataRequired
 import etesync as api
 from etesync_dav.config import ETESYNC_URL
 from etesync_dav.manage import Manager
-from etesync_dav.mac_helpers import generate_cert, macos_trust_cert, needs_ssl, has_ssl
+from etesync_dav.mac_helpers import generate_cert, trust_cert, needs_ssl, has_ssl
 from .radicale.etesync_cache import EteSyncCache, etesync_for_user
 
 manager = Manager()
@@ -126,7 +126,7 @@ def login():
     form = LoginForm(request.form)
     if form.validate_on_submit():
         try:
-            api.Authenticator(ETESYNC_URL).get_auth_token(form.username.data, form.login_password.data)
+            manager.refresh_token(form.username.data, form.login_password.data)
             login_user(form.username.data)
             return redirect(url_for('account_list'))
         except Exception as e:
@@ -185,7 +185,7 @@ def certgen():
     form = FlaskForm(request.form)
     if form.validate_on_submit():
         generate_cert()
-        macos_trust_cert()
+        trust_cert()
 
         return shutdown_response()
 
